constEndAngle method
Defines the Pie.endAngle-accessor as a constant function that always returns the specified value.
Implementation
void constEndAngle(num endAngle) {
this.endAngle = constant(endAngle);
}
Defines the Pie.endAngle-accessor as a constant function that always returns the specified value.
void constEndAngle(num endAngle) {
this.endAngle = constant(endAngle);
}