constStartAngle method
Defines the Pie.startAngle-accessor as a constant function that always returns the specified value.
Implementation
void constStartAngle(num startAngle) {
this.startAngle = constant(startAngle);
}
Defines the Pie.startAngle-accessor as a constant function that always returns the specified value.
void constStartAngle(num startAngle) {
this.startAngle = constant(startAngle);
}